import { loadMarkdocConfig } from "./load-config.js";
import { setupConfig } from "./runtime.js";
const markdocConfigId = "astro:markdoc-config";
const resolvedMarkdocConfigId = "\0" + markdocConfigId;
function vitePluginMarkdocConfig({ astroConfig }) {
  return {
    name: "@astrojs/markdoc:config",
    resolveId(id) {
      if (id === markdocConfigId) {
        return resolvedMarkdocConfigId;
      }
    },
    async load(id) {
      if (id !== resolvedMarkdocConfigId)
        return;
      const markdocConfigResult = await loadMarkdocConfig(astroConfig);
      if (!markdocConfigResult) {
        return `export default {}`;
      }
      const { config: unresolvedConfig, fileUrl } = markdocConfigResult;
      const config = await setupConfig(unresolvedConfig);
      const tagRenderPathnameMap = getRenderUrlMap(config.tags ?? {});
      const nodeRenderPathnameMap = getRenderUrlMap(config.nodes ?? {});
      const code = `import { setupConfig, setupConfigSync, resolveComponentImports } from '@astrojs/markdoc/runtime';
			import userConfig from ${JSON.stringify(fileUrl.pathname)};${astroConfig.experimental.assets ? `
import { experimentalAssetsConfig } from '@astrojs/markdoc/experimental-assets-config';
userConfig.nodes = { ...experimentalAssetsConfig.nodes, ...userConfig.nodes };` : ""}
			${getStringifiedImports(tagRenderPathnameMap, "Tag")};
			${getStringifiedImports(nodeRenderPathnameMap, "Node")};

			const tagComponentMap = ${getStringifiedMap(tagRenderPathnameMap, "Tag")};
			const nodeComponentMap = ${getStringifiedMap(nodeRenderPathnameMap, "Node")};

			export async function getConfig(configOverrides = {}) {
				const config = await setupConfig(userConfig, configOverrides);
				return resolveComponentImports(config, tagComponentMap, nodeComponentMap);
			}
			
			${/* used by `getHeadings()`. This bypasses `extends` resolution, which can be async */
      ""}
			export function getConfigSync() {
				return setupConfigSync(userConfig);
			}`;
      return code;
    }
  };
}
function getRenderUrlMap(tagsOrNodes) {
  const renderPathnameMap = {};
  for (const [name, value] of Object.entries(tagsOrNodes)) {
    if (value.render instanceof URL) {
      renderPathnameMap[name] = value.render.pathname;
    }
  }
  return renderPathnameMap;
}
function getStringifiedImports(renderUrlMap, componentNamePrefix) {
  let stringifiedComponentImports = "";
  for (const [key, renderUrl] of Object.entries(renderUrlMap)) {
    stringifiedComponentImports += `import ${componentNamePrefix + key} from ${JSON.stringify(
      renderUrl + "?astroPropagatedAssets"
    )};
`;
  }
  return stringifiedComponentImports;
}
function getStringifiedMap(renderUrlMap, componentNamePrefix) {
  let stringifiedComponentMap = "{";
  for (const key in renderUrlMap) {
    stringifiedComponentMap += `${key}: ${componentNamePrefix + key},
`;
  }
  stringifiedComponentMap += "}";
  return stringifiedComponentMap;
}
export {
  markdocConfigId,
  resolvedMarkdocConfigId,
  vitePluginMarkdocConfig
};
